@@ -18,6 +18,13 @@ from .tools import (
     register_tool_provider,
     ToolProvider,
 )
+from .audio import (
+    get_audio_format,
+    is_format_supported,
+    convert_audio_to_wav,
+    ensure_supported_format,
+    check_ffmpeg_available,
+)
 
 __all__ = [
     # File utilities
@@ -34,4 +41,10 @@ __all__ = [
     "get_tool_provider",
     "register_tool_provider",
     "ToolProvider",
+    # Audio utilities
+    "get_audio_format",
+    "is_format_supported",
+    "convert_audio_to_wav",
+    "ensure_supported_format",
+    "check_ffmpeg_available",
 ]
\ No newline at end of file
